@@ -55,12 +55,21 @@ request_search(const char *s, const char *page, const char *order)
 int
 extractjson(const char *s, char **start, char **end)
 {
-	if (!(*start = strstr(s, "window[\"ytInitialData\"] = ")))
+	*start = strstr(s, "window[\"ytInitialData\"] = ");
+	if (*start) {
+		(*start) += sizeof("window[\"ytInitialData\"] = ") - 1;
+	} else {
+		*start = strstr(s, "var ytInitialData = ");
+		if (*start)
+			(*start) += sizeof("var ytInitialData = ") - 1;
+	}
+	if (!*start)
 		return -1;
-	if (!(*end = strstr(*start, "};\n")))
+	*end = strstr(*start, "};\n");
+	if (!*end)
+		*end = strstr(*start, "}; \n");
+	if (!*end)
 		return -1;
-
-	(*start) += sizeof("window[\"ytInitialData\"] = ") - 1;
 	(*end)++;
 
 	return 0;
