@@ -18,5 +18,4 @@ struct search_response {
 };
 
 struct search_response *
-youtube_search(const char *rawsearch, const char *chan, const char *user,
-               const char *page, const char *order);
+youtube_search(const char *rawsearch, const char *page, const char *order);
